@@ -23,7 +23,8 @@ CREATION_ATTRIBUTES = ['name', 'image', 'command', 'cpu', 'memory',
                        'environment', 'workdir', 'labels', 'image_pull_policy',
                        'restart_policy', 'interactive', 'image_driver',
                        'security_groups', 'hints', 'nets', 'auto_remove',
-                       'runtime', 'hostname', 'mounts', 'disk']
+                       'runtime', 'hostname', 'mounts', 'disk',
+                       'availability_zone', 'auto_heal']
 
 
 class Container(base.Resource):
@@ -43,7 +44,7 @@ class ContainerManager(base.Manager):
             return '/v1/containers'
 
     def list(self, marker=None, limit=None, sort_key=None,
-             sort_dir=None, detail=False, all_projects=False):
+             sort_dir=None, detail=False, all_projects=False, **kwargs):
         """Retrieve a list of containers.
 
         :param all_projects: Optional, list containers in all projects
@@ -76,7 +77,6 @@ class ContainerManager(base.Manager):
 
         filters = utils.common_filters(marker, limit, sort_key,
                                        sort_dir, all_projects)
-
         path = ''
         if detail:
             path += 'detail'
@@ -85,7 +85,7 @@ class ContainerManager(base.Manager):
 
         if limit is None:
             return self._list(self._path(path),
-                              "containers")
+                              "containers", qparams=kwargs)
         else:
             return self._list_pagination(self._path(path),
                                          "containers",
@@ -130,8 +130,9 @@ class ContainerManager(base.Manager):
         return self._action(id, '/stop',
                             qparams={'timeout': timeout})
 
-    def rebuild(self, id):
-        return self._action(id, '/rebuild')
+    def rebuild(self, id, **kwargs):
+        return self._action(id, '/rebuild',
+                            qparams=kwargs)
 
     def restart(self, id, timeout):
         return self._action(id, '/reboot',
@@ -215,9 +216,9 @@ class ContainerManager(base.Manager):
         return self._action(container, '/network_detach',
                             qparams={'network': network})
 
-    def network_attach(self, container, network):
+    def network_attach(self, container, **kwargs):
         return self._action(container, '/network_attach',
-                            qparams={'network': network})
+                            qparams=kwargs)
 
     def network_list(self, container):
         return self._list(self._path(container) + '/network_list',
